==> haskell-wai-app-file-cgi-3.1.10-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-3C0W6qTOP8jJ2TwXoLYLBN
key:                  wai-app-file-cgi-3.1.10-3C0W6qTOP8jJ2TwXoLYLBN
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  7bb4e238b954a66158c2eeb2ff8e19bb
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-3C0W6qTOP8jJ2TwXoLYLBN
depends:
    array-0.5.4.0 attoparsec-0.14.4-Gj1vArEZdggJnxQ5I0nGMx
    base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-LFqu6hRGbna4Vnd1Zm6Vxy
    conduit-1.3.4.2-l5Gjd0GDDY6sXJjy2eVBb
    conduit-extra-1.3.6-1YQmsZupa4n4BF07bgEynC containers-0.6.4.1
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO directory-1.3.6.2
    filepath-1.4.2.1 http-client-0.7.12-AeB5BHvtH8k8m0ALRd1z9y
    http-conduit-2.3.8-FFmJd4ZWgx79Sx0dOaXYbp
    http-date-0.0.11-2gwhiLGmQLNJoOXkFYR6Ej
    http-types-0.12.3-HpvMf1FhGSo5yZ9uunhMJt
    mime-types-0.1.0.9-7GDM5km4xFM2oMJfUcH43l
    network-3.1.2.7-3dAlKyu2TU91rkKNmDqxd9 process-1.6.13.2
    sockaddr-0.0.0-Fbi9AABhHiR4ctVuEQujB6
    static-hash-0.0.1-BLGP91vhDTzJ5y94e2JHpe text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.3-5KXCDhZ1Y9gJG0n8nwx5FU
    wai-conduit-3.0.0.4-HFZ0CC3H2WrDBsXsxWPJ6V
    warp-3.3.22-9Pep9M85MEr6Yu58bFecb3
    word8-0.1.3-AazxEC5xyKiELvx3OUlEW

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.10-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-K9hqmnLuOvJvWC0xazU1E
key:                  wai-app-file-cgi-3.1.10-K9hqmnLuOvJvWC0xazU1E
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  17392275a98cc527ce7f4a7f3d0d1045
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-K9hqmnLuOvJvWC0xazU1E
depends:
    array-0.5.4.0 attoparsec-0.14.4-R00hSHCjmo7OsW0dxMCO2 base-4.15.1.0
    bytestring-0.10.12.1 case-insensitive-1.2.1.0-G4kgJFtuNP5ARaby10fUk
    conduit-1.3.4.2-CMk7OHvx9XxoVaDRukWNn
    conduit-extra-1.3.6-C3i0kTSOQZoCIbp1xDRYV5 containers-0.6.4.1
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO directory-1.3.6.2
    filepath-1.4.2.1 http-client-0.7.13.1-Dh7SR0m1x6o3yipHdw5yVA
    http-conduit-2.3.8-FE99r2a3r25LMiqszoJLHT
    http-date-0.0.11-42dRXCygRhSKUigzZ0w6j0
    http-types-0.12.3-Llvk7L15ADrHHwahvWBt9z
    mime-types-0.1.0.9-7GDM5km4xFM2oMJfUcH43l
    network-3.1.2.7-3MnWjnNhABh27tP7sbt8Ba process-1.6.13.2
    sockaddr-0.0.1-3IUQGfUcHxq1yO7pc7igbz
    static-hash-0.0.2-1v760WUVif0DCsG2YiL39U text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.3-5MclZ0BnnemDnlcTXRG31
    wai-conduit-3.0.0.4-5KBJKD1dHpoGerJCDSpHPN
    warp-3.3.22-GLEQDOwt1cCHypz8BwJdkC
    word8-0.1.3-AazxEC5xyKiELvx3OUlEW

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
